@@ -269,7 +269,7 @@ extern "C" {
     PsychError  PsychHIDOSGamePadAxisQuery(int deviceIndex, int axisId, double* min, double* max, double* val, char* axisLabel);
     int         PsychHIDGetDefaultKbQueueDevice(void);
 
-    PsychError  PsychHIDOSKbQueueCreate(int deviceIndex, int numScankeys, int* scanKeys, int numValuators, int numSlots, unsigned int flags, unsigned int windowHandle);
+    PsychError  PsychHIDOSKbQueueCreate(int deviceIndex, int numScankeys, int* scanKeys, int numValuators, int numSlots, unsigned int flags, psych_uint64 windowHandle);
     void        PsychHIDOSKbQueueRelease(int deviceIndex);
     void        PsychHIDOSKbQueueStop(int deviceIndex);
     void        PsychHIDOSKbQueueStart(int deviceIndex);
