@@ -1,35 +1,35 @@
 /*
-	PsychToolbox3/Source/Common/Screen/PsychGraphicsCardRegisterSpecs.h		
+    PsychToolbox3/Source/Common/Screen/PsychGraphicsCardRegisterSpecs.h
 
-	AUTHORS:
-	
-		mario.kleiner@tuebingen.mpg.de		mk
-        Alex Deucher.
+    AUTHORS:
 
-	PLATFORMS:	
-	
-		All.
+        mario.kleiner.de@gmail.com      mk
+        Alex Deucher (indirectly - by providing useful pointers and hints)
 
-	HISTORY:
-	
-	01/12/2008	mk		Created.
-	
-	DESCRIPTION:
+    PLATFORMS:
 
-	This file contains specifications of the low-level registers of different graphics
-	cards.
-	
-	Currently it contains register offsets for recent ATI GPU's and some NVIDIA GPU's.
+        All.
+
+    HISTORY:
+
+    01/12/2008    mk        Created.
+
+    DESCRIPTION:
+
+    This file contains specifications of the low-level registers of different graphics
+    cards.
+
+    Currently it contains register offsets for recent ATI GPU's and some NVIDIA GPU's.
 
     Copyright:
-    
+
     Parts of this file are direct copies of register defines from the Linux Radeon KMS
     driver. The file is copyright 2008-2011 Mario Kleiner and also
     Copyright 2010 Advanced Micro Devices, Inc.
     Authors: Alex Deucher
-    
+
     License:
-    
+
     *
     * Permission is hereby granted, free of charge, to any person obtaining a
     * copy of this software and associated documentation files (the "Software"),
@@ -57,7 +57,7 @@
 #define PSYCH_IS_INCLUDED_PsychGraphicsCardRegisterSpecs
 
 // PCI vendor ids:
-#define PCI_VENDOR_ID_NVIDIA	0x10de
+#define PCI_VENDOR_ID_NVIDIA    0x10de
 #define PCI_VENDOR_ID_AMD       0x1022
 #define PCI_VENDOR_ID_ATI       0x1002
 #define PCI_VENDOR_ID_INTEL     0x8086
@@ -68,9 +68,6 @@
 #define kPsychRadeon   2
 #define kPsychIntelIGP 3
 
-// Maximum number of crtc's on DCE-4 style Radeon hardware:
-#define DCE4_MAXHEADID 5
-
 // The following register offsets and specs are taken from the official AMD/ATI
 // specs, downloadable from http://www.x.org/docs/AMD/ the website of the X-ORG
 // foundation, home of the open source Linux X11 server. These specs are official
@@ -81,7 +78,7 @@
 #define RADEON_R500_GEN_INT_STATUS 0x044
 
 // Display controller interrupt occured? [Selection mask]:
-#define RADEON_R500_DISPLAY_INT_STATUS	(1 << 0)
+#define RADEON_R500_DISPLAY_INT_STATUS    (1 << 0)
 
 // Interrupt status register for reporting of display controller interrupts:
 #define RADEON_R500_DISP_INTERRUPT_STATUS 0x7edc
@@ -143,10 +140,15 @@
 // (fullscreen onscreen windows open), they change at each Screen('Flip') execution, ie.
 // at each completed double-buffer swap. They toggle between the VRAM addresses of the two
 // (or four in stereo) buffers when they are exchanged:
-#define RADEON_D1GRPH_PRIMARY_SURFACE_ADDRESS	0x6110 
-#define RADEON_D1GRPH_SECONDARY_SURFACE_ADDRESS 0x6118
-#define RADEON_D2GRPH_PRIMARY_SURFACE_ADDRESS	0x6910 
-#define RADEON_D2GRPH_SECONDARY_SURFACE_ADDRESS 0x6918
+#define RADEON_D1GRPH_PRIMARY_SURFACE_ADDRESS    0x6110
+#define RADEON_D1GRPH_SECONDARY_SURFACE_ADDRESS  0x6118
+#define RADEON_D2GRPH_PRIMARY_SURFACE_ADDRESS    0x6910
+#define RADEON_D2GRPH_SECONDARY_SURFACE_ADDRESS  0x6918
+
+#define RADEON_D1GRPH_UPDATE                    0x6144
+#define RADEON_D2GRPH_UPDATE                    0x6944
+#define RADEON_SURFACE_UPDATE_PENDING           4
+#define RADEON_SURFACE_UPDATE_TAKEN             8
 
 // Bit 0 of these enables (Setting of 0) or disables (Setting of 1 aka 0x1) internal routing
 // the VSYNC signal (aka V_UPDATE), so this can prevent/hold back the double-buffered
@@ -154,12 +156,12 @@
 // TODO TEST: Can this be used to delay flips, e.g., until some deadline is reached
 // or some user defined trigger condition occurs, e.g., kernel-level sync swaps to
 // trigger condition?
-#define RADEON_D1MODE_MASTER_UPDATE_LOCK		0x60E0
-#define RADEON_D2MODE_MASTER_UPDATE_LOCK		0x68E0
+#define RADEON_D1MODE_MASTER_UPDATE_LOCK        0x60E0
+#define RADEON_D2MODE_MASTER_UPDATE_LOCK        0x68E0
 
 // Encodes pitch (length of a single scanline in pixels) as stored in the framebuffer:
 #define RADEON_D1GRPH_PITCH 0x6120
-#define RADEON_D2GRPH_PITCH 0x6920 
+#define RADEON_D2GRPH_PITCH 0x6920
 
 // These registers control operation of the color/gamma hardware lookup tables:
 // Bit 0 selects if hardware LUT A or B should be used for the given display pipeline.
@@ -167,8 +169,8 @@
 // if a 10 bit per color channel framebuffer is used, should the 8->10 LUT's be ignored
 // and the 10 bit values directly output to the RAMDAC's/TDMS/LVDS emitters? Usually
 // you want to enable this bypass in 10 bpc mode for best results:
-#define RADEON_D1GRPH_LUT_SEL	0x6108
-#define RADEON_D2GRPH_LUT_SEL	0x6908
+#define RADEON_D1GRPH_LUT_SEL    0x6108
+#define RADEON_D2GRPH_LUT_SEL    0x6908
 
 // These registers control the color depth and pixel formatting in the framebuffer -
 // or better: The interpretation of the data by the CRTC's. They don't affect the
@@ -181,8 +183,8 @@
 // always renders in 8888 format, you'll experience corrupted screen colors, unless
 // you use the PTB imaging pipeline for automatic reformatting of floating point
 // HDR images to RGBA8 formatted data, suitable for 2101010 mode. :-)
-#define RADEON_D1GRPH_CONTROL	0x6104
-#define RADEON_D2GRPH_CONTROL	0x6904
+#define RADEON_D1GRPH_CONTROL    0x6104
+#define RADEON_D2GRPH_CONTROL    0x6904
 
 // These registers control output bit depths over TMDS, LVTM, DVO emitters,
 // as well as the method to reduce the bit depths in a visually pleasing way
@@ -240,6 +242,7 @@
 #define EVERGREEN_DC_LUT_WHITE_OFFSET_RED               0x6a18
 #define EVERGREEN_DC_LUT_10BIT_BYPASS                   0x6808
 #define EVERGREEN_GRPH_CONTROL                          0x6804
+#define EVERGREEN_GRPH_ENABLE                           0x6800
 
 /* display controller offsets used for crtc/cur/lut/grph/viewport/etc. */
 #define EVERGREEN_CRTC0_REGISTER_OFFSET                 (0x6df0 - 0x6df0)
@@ -255,10 +258,24 @@
 #define EVERGREEN_CRTC_CONTROL                          0x6e70
 #       define EVERGREEN_CRTC_MASTER_EN                 (1 << 0)
 #       define EVERGREEN_CRTC_DISP_READ_REQUEST_DISABLE (1 << 24)
+#define EVERGREEN_CRTC_BLANK_CONTROL                    0x6e74
+#       define EVERGREEN_CRTC_BLANK_DATA_EN             (1 << 8)
 #define EVERGREEN_CRTC_STATUS                           0x6e8c
 #define EVERGREEN_CRTC_STATUS_POSITION                  0x6e90
 #define EVERGREEN_CRTC_UPDATE_LOCK                      0x6ed4
 
+// Primary/Secondary scanout buffer start addresses - low 32-Bits:
+#define EVERGREEN_GRPH_PRIMARY_SURFACE_ADDRESS          0x6810
+#define EVERGREEN_GRPH_SECONDARY_SURFACE_ADDRESS        0x6814
+
+// upper 32-Bits:
+#define EVERGREEN_GRPH_PRIMARY_SURFACE_ADDRESS_HIGH     0x681c
+#define EVERGREEN_GRPH_SECONDARY_SURFACE_ADDRESS_HIGH   0x6820
+
+// Flip status and control:
+#define EVERGREEN_GRPH_UPDATE                           0x6844
+#       define EVERGREEN_GRPH_SURFACE_UPDATE_PENDING    (1 << 2)
+
 // Evergreen DCE-4 dithering control registers:
 // Basics like on AVIVO: All zero disables dithering/bit depths truncation,
 // Bits for enable are like cases a), b), c) above, but the meaning
@@ -326,18 +343,29 @@
 #       define NI_REGAMMA_PROG_B                       4
 #       define NI_OVL_REGAMMA_MODE(x)                  (((x) & 0x7) << 4)
 
-// Offset of crtc blocks of evergreen gpu's for each of the six possible crtc's:
-static const unsigned int crtcoff[(DCE4_MAXHEADID + 1)] = { EVERGREEN_CRTC0_REGISTER_OFFSET, EVERGREEN_CRTC1_REGISTER_OFFSET, EVERGREEN_CRTC2_REGISTER_OFFSET, EVERGREEN_CRTC3_REGISTER_OFFSET, EVERGREEN_CRTC4_REGISTER_OFFSET, EVERGREEN_CRTC5_REGISTER_OFFSET };
+#define NI_REGAMMA_LUT_INDEX                               0x6a84
+#define NI_REGAMMA_LUT_DATA                                0x6a88
+
+/* "Volcanic Islands" DCE10/11 display controller offsets used for crtc/cur/lut/grph/viewport/etc. */
+/* These are from amdgpu's vid.h defines. Multiply by 4 as we expect byte offsets, but vid.h defines
+ * dword (= 4 bytes) aligned offsets. */
+#define DCE10_CRTC0_REGISTER_OFFSET                 ((0x1b9c - 0x1b9c) * 4)
+#define DCE10_CRTC1_REGISTER_OFFSET                 ((0x1d9c - 0x1b9c) * 4)
+#define DCE10_CRTC2_REGISTER_OFFSET                 ((0x1f9c - 0x1b9c) * 4)
+#define DCE10_CRTC3_REGISTER_OFFSET                 ((0x419c - 0x1b9c) * 4)
+#define DCE10_CRTC4_REGISTER_OFFSET                 ((0x439c - 0x1b9c) * 4)
+#define DCE10_CRTC5_REGISTER_OFFSET                 ((0x459c - 0x1b9c) * 4)
+#define DCE10_CRTC6_REGISTER_OFFSET                 ((0x479c - 0x1b9c) * 4)
 
 // NVIDIA REGISTERS:
 // -----------------
 
 // Card/Core id, e.g., NV20,30,40,... encoded in some bits:
-#define NV03_PMC_BOOT_0		0x00000000
+#define NV03_PMC_BOOT_0        0x00000000
 // Encodes or sets byte order (endianity) of card, starting with NV10:
 // As OS/X only supports NV10 or later, we can use it unconditionally.
 // On read: 0 == LE, non-0 == BE. On write, just write 0x00000001 to switch
 // card to host system byte order:
-#define NV03_PMC_BOOT_1		0x00000004
+#define NV03_PMC_BOOT_1        0x00000004
 
 #endif // include once.
