@@ -79,7 +79,10 @@ static char synopsisString[] =
     "flags is passed. A currently supported flag is the symbolic constant kPsychGUIWindow. It enables windows "
     "to behave more like regular GUI windows on your system. See 'help kPsychGUIWindow' for more info. The "
     "flag kPsychGUIWindowWMPositioned additionally leaves initial positioning of the GUI window to the window "
-    "manager.\n\n"
+    "manager. The flag kPsychExternalDisplayMethod marks this onscreen window as not an actual visual "
+    "stimulation surface, ie. actual visual stimulation is provided by some other external display mechanism, "
+    "e.g., Vulkan or some VR compositor or such. This tells Screen() to suppress certain warnings or checks "
+    "which would be prudent if the window were the primary and critical means of visual stimulation.\n\n"
     "\"clientRect\" This optional parameter allows to define a size of the onscreen windows drawing area "
     "that is different from the actual size of the windows framebuffer. If set, then the imaging pipeline "
     "is started and a virtual framebuffer of the size of \"clientRect\" is created. Your code will draw "
@@ -310,7 +313,7 @@ PsychError SCREENOpenWindow(void)
 
     specialflags = 0;
     PsychCopyInIntegerArg64(9,FALSE, &specialflags);
-    if (specialflags < 0 || (specialflags > 0 && !(specialflags & (kPsychGUIWindow | kPsychGUIWindowWMPositioned))))
+    if (specialflags < 0 || (specialflags > 0 && !(specialflags & (kPsychGUIWindow | kPsychGUIWindowWMPositioned | kPsychExternalDisplayMethod))))
         PsychErrorExitMsg(PsychError_user, "Invalid 'specialflags' provided.");
 
     // Alloc in optional double vector with VRR mode and parameters:
@@ -333,13 +336,13 @@ PsychError SCREENOpenWindow(void)
             if (stereomode == kPsychDualWindowStereo)
                 PsychErrorExitMsg(PsychError_user, "Use of VRR mode for fine-grained stimulus presentation timing is incompatible with dual-window stereo presentation on separate screens, as their timing can't be synchronized in VRR mode, as needed for artifact-free dual-display stereo. Choose either VRR or this stereo mode. Aborting.");
 
-            if (imagingmode == kPsychNeedDualWindowOutput)
+            if (imagingmode & kPsychNeedDualWindowOutput)
                 PsychErrorExitMsg(PsychError_user, "Use of VRR mode for fine-grained stimulus presentation timing is incompatible with Screen's own display mirroring or dual-pipe operations on separate screens. Choose either VRR or one of these. Aborting.");
 
             if (stereomode == kPsychDualStreamStereo)
                 PsychErrorExitMsg(PsychError_user, "Use of VRR mode for fine-grained stimulus presentation timing is incompatible with dual-stream stereo presentation on special display devices. Choose either VRR or this stereo mode. Aborting.");
 
-            if (imagingmode == kPsychNeedFinalizedFBOSinks)
+            if (imagingmode & kPsychNeedFinalizedFBOSinks)
                 PsychErrorExitMsg(PsychError_user, "Use of VRR mode for fine-grained stimulus presentation timing is incompatible with use of finalized FBO sinks on special display devices. Choose either VRR or finalized FBO sinks. Aborting.");
         }
 
@@ -848,7 +851,7 @@ PsychError SCREENOpenWindow(void)
 
             // Convert windowShieldingLevel 1000 - 1499 and 1500 - 1999 to alpha range 0.0 - 1.0 and
             // assign it as parameter string for our builtin post-multiply function:
-            snprintf(configAlphaString, sizeof(configAlphaString), "%f", (((float) (windowShieldingLevel % 500)) / 499.0));
+            snprintf(configAlphaString, sizeof(configAlphaString), "%1.3f", (((float) (windowShieldingLevel % 500)) / 499.0));
 
             // Add call to our builtin post-multiply function to the end of the finalizer blit chain for left-eye/mono buffer:
             PsychPipelineAddBuiltinFunctionToHook(windowRecord, "LeftFinalizerBlitChain", "Builtin:AlphaPostMultiply", INT_MAX, configAlphaString);
@@ -886,8 +889,11 @@ PsychError SCREENOpenWindow(void)
         // Do three immediate bufferswaps by an internal call to Screen('Flip'). This will also
         // take care of clearing the backbuffer in preparation of first userspace drawing
         // commands and such. We need up-to 3 calls to clear triple-buffered setups from framebuffer junk.
+        windowRecord->specialflags |= kPsychSkipTimestampingForFlipOnce;
         PsychFlipWindowBuffers(windowRecord, 0, 0, 0, 0, &dummy1, &dummy2, &dummy3, &dummy4);
+        windowRecord->specialflags |= kPsychSkipTimestampingForFlipOnce;
         PsychFlipWindowBuffers(windowRecord, 0, 0, 0, 0, &dummy1, &dummy2, &dummy3, &dummy4);
+        windowRecord->specialflags |= kPsychSkipTimestampingForFlipOnce;
         PsychFlipWindowBuffers(windowRecord, 0, 0, 0, 0, &dummy1, &dummy2, &dummy3, &dummy4);
         // Display now shows background color, so user knows that PTB's 'OpenWindow'
         // procedure is successfully finished.
