@@ -143,11 +143,12 @@ PsychError SCREENConfigureDisplay(void)
                     "Readonly properties:\n\n"
                     "* Display size \"displayWidthMM\" x \"displayHeightMM\" in millimeters, as reported by attached display.\n"
                     "* Video output name \"name\".\n"
+                    "* Video output handle \"outputHandle\". On Linux/X11 this is the numeric XID of the associated RandR video output.\n"
                     "\nProviding invalid or incompatible settings will raise an error.\n";
 
     static char seeAlsoString[] = "Screen('Resolutions'), Screen('Resolution');";
 
-    const char *OutputFieldNames[] = { "width", "height", "pixelSize", "hz", "xStart", "yStart", "name", "displayWidthMM", "displayHeightMM" };
+    const char *OutputFieldNames[] = { "width", "height", "pixelSize", "hz", "xStart", "yStart", "name", "outputHandle", "displayWidthMM", "displayHeightMM" };
     char *settingName = NULL;
     int screenNumber, outputId, ditherEnable;
 
@@ -512,7 +513,16 @@ PsychError SCREENConfigureDisplay(void)
     if(outputId < 0 || outputId >= kPsychMaxPossibleCrtcs) PsychErrorExitMsg(PsychError_user, "Invalid display output index provided.");
 
     // Create a structure and populate it.
-    PsychAllocOutStructArray(1, FALSE, -1, 9, OutputFieldNames, &oldResStructArray);
+    PsychAllocOutStructArray(1, FALSE, -1, 10, OutputFieldNames, &oldResStructArray);
+
+    // Query and return output name, and physical size of display in mm:
+    unsigned long mm_width, mm_height;
+    RROutput output_xid;
+
+    PsychSetStructArrayStringElement("name", 0, (char*) PsychOSGetOutputProps(screenNumber, outputId, FALSE, &mm_width, &mm_height, &output_xid), oldResStructArray);
+    PsychSetStructArrayDoubleElement("outputHandle", 0, (double) output_xid, oldResStructArray);
+    PsychSetStructArrayDoubleElement("displayWidthMM", 0, mm_width, oldResStructArray);
+    PsychSetStructArrayDoubleElement("displayHeightMM", 0, mm_height, oldResStructArray);
 
     // Query current video mode of this output:
     XRRCrtcInfo *crtc_info = NULL;
@@ -521,25 +531,22 @@ PsychError SCREENConfigureDisplay(void)
     XRRModeInfo *mode = PsychOSGetModeLine(screenNumber, outputId, &crtc_info);
     PsychUnlockDisplay();
 
-    if (NULL == mode) PsychErrorExitMsg(PsychError_user, "Could not query video mode for this output. Invalid outputId or unsupported function on this system?");
-
     // Get (x,y) top-left corner of crtc's viewport -- panning info:
-    PsychSetStructArrayDoubleElement("xStart", 0, (double) crtc_info->x, oldResStructArray);
-    PsychSetStructArrayDoubleElement("yStart", 0, (double) crtc_info->y, oldResStructArray);
-    XRRFreeCrtcInfo(crtc_info);
+    PsychSetStructArrayDoubleElement("xStart", 0, (double) ((crtc_info) ? crtc_info->x : 0), oldResStructArray);
+    PsychSetStructArrayDoubleElement("yStart", 0, (double) ((crtc_info) ? crtc_info->y : 0), oldResStructArray);
+    if (crtc_info)
+        XRRFreeCrtcInfo(crtc_info);
+
+    crtc_info = NULL;
+
+    // Note: mode would be NULL on a disabled output.
 
     // Query and return resolution:
-    newWidth = (int) mode->width;
-    newHeight = (int) mode->height;
+    newWidth = (int) ((mode) ? mode->width : 0);
+    newHeight = (int) ((mode) ? mode->height : 0);
     PsychSetStructArrayDoubleElement("width", 0, newWidth, oldResStructArray);
     PsychSetStructArrayDoubleElement("height", 0, newHeight, oldResStructArray);
 
-    // Query and return output name, and physical size of display in mm:
-    unsigned long mm_width, mm_height;
-    PsychSetStructArrayStringElement("name", 0, (char*) PsychOSGetOutputProps(screenNumber, outputId, &mm_width, &mm_height, NULL), oldResStructArray);
-    PsychSetStructArrayDoubleElement("displayWidthMM", 0, mm_width, oldResStructArray);
-    PsychSetStructArrayDoubleElement("displayHeightMM", 0, mm_height, oldResStructArray);
-
     // Query and return refresh rate:
 
     // Modeline with plausible values returned by RandR?
@@ -583,28 +590,35 @@ PsychError SCREENConfigureDisplay(void)
 PsychError SCREENResolution(void)
 {
     static char useString[] = "oldResolution=Screen('Resolution', screenNumber [, newwidth][, newheight][, newHz][, newPixelSize][, specialMode]);";
-    static char synopsisString[] =	"Query or change display settings for screen \"screenNumber\".\n"
+    static char synopsisString[] = "Query or change display settings for screen \"screenNumber\".\n"
                     "Returns a struct \"oldResolutions\" with the current settings for screen "
                     "resolution, refresh rate and pixel depth. Optionally sets new settings "
                     "for screen resolution \"newwidth\" x \"newheight\", refresh rate \"newHz\" "
                     "and framebuffer pixel depth \"newPixelSize\". Providing invalid or incompatible "
                     "settings will raise an error. Especially the color depth \"newPixelSize\" should "
-                    "usually not be set to anything else than its default of 32 bpp or 24 bpp. "
+                    "usually not be set to anything else than its default of 32 bpp or 24 bpp, iow. it "
+                    "should be best left alone. "
                     "Other settings can impair alpha-blending on some systems, a setting of 16 bpp "
                     "will disable alpha-blending and create drastically reduced color resolution of "
                     " 5 bits per color channel. "
                     "A setting of 8 bpp is not supported at all on MacOS/X and will create artifacts "
                     "on all other systems. Use a size of 32 bpp even for clut animation. This function "
                     "may not work on all MS-Windows setups, your mileage may vary...\n"
-                    "On Linux the function only switches display settings in the conventional sense on "
-                    "a single-display setup. On a multi-display setup, this function only changes the "
-                    "total size of the framebuffer, ie., 'newwidth' and 'newheight', the other "
-                    "parameters are silently ignored. On Linux, the video settings of each individual display, "
-                    "e.g., resolution, video refresh rate, panning, are queried and changed via the "
-                    "Screen('ConfigureDisplay') function instead. This allows for much more flexibility, "
-                    "e.g., you can have a framebuffer bigger than the combined resolution of all displays "
-                    "and only show a fraction of it. You can change the relative position of all physical "
-                    "displays, configure \"mirror modes\", \"side by side\", or \"on top of each other\" "
+                    "On Linux/X11 with the classic X-Server, the function only switches display settings "
+                    "in the conventional sense on a single-display setup, or on a multi-X-screen setup with "
+                    "one display per X-Screen. On a multi-display-per-X-Screen setup, this function only "
+                    "changes the total size of the framebuffer, ie., 'newwidth' and 'newheight', the other "
+                    "parameters are silently ignored. You can create X-Screens and fullscreen onscreen "
+                    "windows that are bigger than what is actually displayable on your attached displays. "
+                    "This allows for some interesting special tricks if you know what you are doing, but can "
+                    "also cause quite a bit of confusion. We recommend using this function on setups with "
+                    "a single display or a single display for each X-Screen (as listed by Screen('Screens'). "
+                    "On Linux/X11 setups with multiple attached displays per X-Screen, the video settings "
+                    "of each individual display, e.g., resolution, video refresh rate, panning, can be queried "
+                    "and changed via the Screen('ConfigureDisplay') function instead. This allows for more "
+                    "flexibility, e.g., you can have a framebuffer bigger than the combined resolution of all "
+                    "displays and only show a fraction of it. You can change the relative position of all "
+                    "physical displays, configure \"mirror modes\", \"side by side\", or \"on top of each other\" "
                     "display configurations.\n"
                     "Psychtoolbox will automatically restore the systems display resolution to the "
                     "system settings made via the display control panel as soon as either your script "
