@@ -34,7 +34,13 @@ function datapixxmakemex()
     end
 
     % Start constructing mex command
-    S = 'mex -v -s';   % -v for verbose output, -s for stripping the files.
+    S = 'mex -v';   % -v for verbose output.
+
+    if IsOctave
+        % -s for stripping the files under Octave:
+        S = [S ' -s'];
+    end
+
     S = [S ' -DPTBMODULE_Datapixx'];
 
     if IsOctave
