@@ -9,7 +9,7 @@ function [nx, ny, textbounds, cache, wordbounds] = DrawFormattedText2(varargin)
 % 
 % When called with a cache struct, the following optional key-value pair
 % arguments are accepted:
-% [, win][, sx][, sy][, xalign][, yalign][, transform][, winRect]
+% [, win][, sx][, sy][, xalign][, yalign][, transform][, winRect][, cacheOnly]
 % 
 % example call:
 % DrawFormattedText2('test text', 'win',window_pointer,'baseColor',[255 0 0])
@@ -99,7 +99,7 @@ function [nx, ny, textbounds, cache, wordbounds] = DrawFormattedText2(varargin)
 % bounding box. Justification options are currently not supported.
 %
 % 'baseColor' is the color in which the text will be drawn (until changed
-% by a <color> format call. This is also the color that will remain active
+% by a <color> format call). This is also the color that will remain active
 % after invocation of this function.
 %
 % 'wrapat', if provided, will automatically break text strings longer than
@@ -301,8 +301,31 @@ if isempty(opt)
 elseif qCalledWithCache
     cache = opt.cache;
     if isfield(cache,'tex')
-        [nx, ny, wordbounds] = deal(cache.nx,cache.ny,cache.wordbounds);
-        DoDrawTexture(opt.win,cache.tex.number,cache.bbox,cache.transform);
+        [nx, ny] = deal(cache.nx,cache.ny);
+        if ~opt.cacheOnly
+            DoDrawTexture(opt.win,cache.tex.number,cache.bbox,cache.transform);
+        end
+    else
+        if ~opt.cacheOnly
+            [nx, ny, textbounds, wordbounds] = DoDraw(opt.win,...
+                disableClip,...
+                cache.px,...
+                cache.py,...
+                cache.bbox,...
+                cache.subStrings,...
+                cache.switches,...
+                cache.fmts,...
+                cache.fmtCombs,...
+                cache.ssBaseLineOff,...
+                cache.winRect,...
+                cache.previous,...
+                cache.righttoleft,...
+                cache.transform,...
+                cache.wordbounds);
+        end
+    end
+    if isfield(cache,'tex') || opt.cacheOnly
+        wordbounds = cache.wordbounds;
         if isempty(cache.transform)
             textbounds = cache.bbox;
         else
@@ -313,22 +336,9 @@ elseif qCalledWithCache
                 wordbounds(b,:)  = transformBBox2(wordbounds(b,:), cache.transform, cache.bbox);
             end
         end
-    else
-        [nx, ny, textbounds, wordbounds] = DoDraw(opt.win,...
-            disableClip,...
-            cache.px,...
-            cache.py,...
-            cache.bbox,...
-            cache.subStrings,...
-            cache.switches,...
-            cache.fmts,...
-            cache.fmtCombs,...
-            cache.ssBaseLineOff,...
-            cache.winRect,...
-            cache.previous,...
-            cache.righttoleft,...
-            cache.transform,...
-            cache.wordbounds);
+        if ~isfield(cache,'tex')
+            [nx,ny] = deal([]);
+        end
     end
     % done
     return;
@@ -1082,7 +1092,7 @@ codes.size (toStrip) = [];
 tstring = tstringOri;
 
 if isempty(tstring)
-    % strong was only formatting commands, nothing to draw, ignore
+    % string was only formatting commands, nothing to draw, ignore
     [fmtCombs,fmts,switches,previous] = deal([]);
     return;
 end
@@ -1121,10 +1131,9 @@ end
 c = [codes.style; codes.color; codes.font; codes.size];
 % where do changes occur?
 switches = logical(diff([[previous.style; 1; 1; previous.size] c],[],2));
-% if user-provided baseColor, make sure it is applied!
-if ~isnumeric(startColor)
-    switches(2,1) = true;
-end
+% make sure color is always applied, may have been changed under our feet
+% if drawn later, or may have been provided as baseColor by user
+switches(2,1) = true;
 % get unique formats and where each of these formats is to be applied
 % the below is equivalent to:
 % [format,~,fmtCombs] = unique(c.','rows');
@@ -1316,6 +1325,7 @@ elseif isstruct(varargs{1})
         'xalign' ,[],...
         'yalign' ,[],...
         'transform',[],...
+        'cacheOnly',false,...
         'winRect',[]...
         );
 else
