@@ -61,6 +61,16 @@ try
     fprintf('Uses the xf86-video-modesetting DDX video driver.\n');
   end
 
+  % RaspberryPi VideoCore4/6?
+  if strcmp(winfo.GPUCoreId, 'VC4')
+    % Raspbian in early 2021 has a bug which prevents pageflipping from working.
+    % Add a workaround to the xorg.conf settings, which will fix it:
+    fprintf('This is likely a RaspberryPi with VideoCore-4 or VideoCore-6 gpu.\n');
+    needPreventDrmModifiers = 1;
+  else
+    needPreventDrmModifiers = 0;
+  end
+
   % Step 2: Enumerate all available video outputs on all X-Screens:
   outputs = [];
   outputCnt = 0;
@@ -517,7 +527,8 @@ end
 
 % Actually any xorg.conf for non-standard settings needed?
 if noautoaddgpu == 0 && multixscreen == 0 && dri3 == 'd' && ismember(useuxa, ['d', 'n']) && triplebuffer == 'd' && modesetting == 'd' && ...
-   ~isempty(intersect(depth30bpp, 'nd')) && ismember(atinotiling, ['d', 'n']) && ~strcmp(xdriver, 'nvidia') && vrrsupport == 'd'
+   ~isempty(intersect(depth30bpp, 'nd')) && ismember(atinotiling, ['d', 'n']) && ~strcmp(xdriver, 'nvidia') && vrrsupport == 'd' && ...
+   needPreventDrmModifiers == 0
 
   % All settings are for a single X-Screen setup with auto-detected outputs
   % and all driver settings on default and not on a NVidia proprietary driver.
@@ -570,6 +581,18 @@ elseif (multixscreen > 0) && (modesetting == 'y') && ~modesettingddxactive
   fprintf('Override: out and in again with this new configuration selected.\n');
 end
 
+% If we want/need to use the intel-ddx, also try to use DRI3/Present, unless user
+% strictly said 'n'o. Why? On modern distros with recent Mesa, OpenGL clients and
+% also desktop GUI's (OpenGL desktop compositors) will choose the new 'iris' OpenGL
+% gallium driver on Intel Gen8+, but the intel-ddx will currently always choose the
+% old i965 DRI classic driver. This mismatch of server/ddx uses i965, but compositor/
+% OpenGL client uses iris, will end in a nice desktop GUI crash, unless we use DRI3!
+% Hard earned wisdom, but with DRI3 we are safe for the moment, so choose that:
+if strcmp(xdriver, 'intel') && (dri3 ~= 'n')
+  fprintf('Override: Use of intel-ddx implies use of DRI3/Present for higher reliability, so enabling DRI3.\n');
+  dri3 = 'y';
+end
+
 % Define filename of output file:
 fdir = PsychtoolboxConfigDir ('XorgConfs');
 
@@ -598,9 +621,19 @@ end
 % Header:
 fprintf(fid, '# Auto generated xorg.conf - Created by Psychtoolbox XOrgConfCreator.\n\n');
 
-if noautoaddgpu > 0
+if noautoaddgpu > 0 || needPreventDrmModifiers
   fprintf(fid, 'Section "ServerFlags"\n');
-  fprintf(fid, '  Option "AutoAddGPU"     "false"\n');
+  if noautoaddgpu
+    fprintf(fid, '  Option "AutoAddGPU"     "false"\n');
+  end
+
+  if needPreventDrmModifiers
+    % Explicitely prevent use of dmabuf_capable flag for modesetting-ddx, as that
+    % can cause broken pageflipping on Raspbian with Linux 5.3 and later.
+    % See: https://gitlab.freedesktop.org/mesa/mesa/-/issues/3601
+    fprintf(fid, '  Option "Debug"     "None"\n');
+  end
+
   fprintf(fid, 'EndSection\n\n');
 end
 
