@@ -81,21 +81,27 @@ if IsOctave
                 fprintf('The following directory should be the *first one* on your Octave path:\n %s \n\n', [PsychtoolboxRoot 'PsychBasic/Octave3LinuxFiles' oext]);
             end
             if IsOSX
-                fprintf('The following directory should be the *first one* on your Octave path:\n %s \n\n', [PsychtoolboxRoot 'PsychBasic/Octave5OSXFiles' oext]);
+                fprintf('The following directory should be the *first one* on your Octave path:\n %s \n\n', [PsychtoolboxRoot 'PsychBasic/Octave6OSXFiles' oext]);
             end
             if IsWindows
-                fprintf('The following directory should be the *first one* on your Octave path:\n %s \n\n', [PsychtoolboxRoot 'PsychBasic\Octave5WindowsFiles' oext]);
+                fprintf('The following directory should be the *first one* on your Octave path:\n %s \n\n', [PsychtoolboxRoot 'PsychBasic\Octave6WindowsFiles' oext]);
             end
         else
             % Correct file with correct extension, still load failure:
             % Check for supported Octave version:
             fprintf('Your version of Octave (%s) might be incompatible with Psychtoolbox: We support Octave 4.0.0 or later\n', version);
-            fprintf('on Linux, Octave 5.1 on Windows and macOS.\n', version);
+            fprintf('on Linux, Octave 6.1 on Windows and macOS.\n');
 
             fprintf('Another reason could be some missing 3rd party dynamic link shared libraries on your system.\n');
             fprintf('Another reason could be some binary incompatibility. You would need to recompile Psychtoolbox from source!\n\n');
         end
     end
+
+    % Our little ad for our troubleshooting services:
+    if exist('PsychPaidSupportAndServices', 'file')
+        PsychPaidSupportAndServices(2);
+    end
+
     error('Missing, inaccessible or dysfunctional Psychtoolbox Mex file for this system, or Octave path wrong. Read the help text above carefully!!\n');
 end
 
@@ -187,5 +193,11 @@ if isempty(inputNames) || ismember(computer, inputNames)
             end
         end
     end
+
+    % Our little ad for our troubleshooting services:
+    if exist('PsychPaidSupportAndServices', 'file')
+        PsychPaidSupportAndServices(2);
+    end
+
     error('Missing or dysfunctional Psychtoolbox Mex file for this operating system. Read the help text above carefully!!');
 end
