@@ -12,6 +12,7 @@ function resultFlag = IsWin(is64)
 % ??/??/?? awi Wrote it.
 % 6/30/06  awi Fixed help section.
 % 6/13/12   dn Added support for 64bit and on windows query
+% 10/16/15  mk Add support for 64-Bit Octave on Windows.
 
 persistent rc;
 persistent rc64;
@@ -21,13 +22,12 @@ if nargin < 1 || isempty(is64)
      is64 = 0;
 end
 
-
 if isempty(rc)
-     rc=streq(computer,'PCWIN') || streq(computer,'PCWIN64') || streq(computer, 'i686-pc-mingw32');
+     rc=streq(computer,'PCWIN') || streq(computer,'PCWIN64') || ~isempty(strfind(computer, 'mingw32'));
 end
 
 if isempty(rc64)
-     rc64 = rc && ~isempty(strfind(computer, '64'));
+     rc64 = rc && (~isempty(strfind(computer, 'x86_64')) || streq(computer,'PCWIN64'));
 end
 
 if is64 == 0
