@@ -42,6 +42,7 @@ function PsychDebugWindowConfiguration(opaqueForHID, opacity)
 % 15.11.2009 mk  Now also for Windows and Linux.
 % 22.08.2013 mk  Disable any high-precision timestamping on all operating systems.
 % 09.09.2013 mk  No special case handling for OSX needed anymore.
+% 31.12.2014 mk  On Wayland, timing is expected to be good, so don't skip sync tests etc.
 
 if nargin < 1
     opaqueForHID = [];
@@ -55,11 +56,17 @@ if nargin < 2
     opacity=0.5;
 end
 
-% Disable high precision timestamping:
-Screen('Preference', 'VBLTimestampingMode', -1);
+% Can only get precise visual stimulation timing/timestamping
+% on a Wayland display server for partially transparent debug windows:
+if ~IsWayland
+    % Not Wayland -> No good timing.
 
-% Skip sync tests:
-Screen('Preference', 'SkipSyncTests', 2);
+    % Disable high precision timestamping:
+    Screen('Preference', 'VBLTimestampingMode', -1);
+
+    % Skip sync tests:
+    Screen('Preference', 'SkipSyncTests', 2);
+end
 
 % Map range 0.0 - 1.0 to 0 - 499:
 opacity = floor(opacity * 499);
