@@ -14,7 +14,7 @@
  * 24-Mar-2011 -- Make 64-bit clean (MK).
  * 27-Mar-2011 -- Remove obsolete and totally bitrotten Octave-2 support (MK).
  * 03-Apr-2011 -- Allow to receive pointers encoded in double's, uint32 or uint64. Adapt dynamically (MK).
- *
+ * 26-Nov-2016 -- Most history is in Git since years, these entries are moot. (MK)
  */
 
 #include "mogltypes.h"
@@ -44,7 +44,7 @@ static int firsttime = 1;
 static int debuglevel = 1;
 
 // Dummymode: If set to a value greater than zero, moglcore does not really execute
-// commands anymore. 
+// commands anymore.
 static int dummymode = 0;
 
 // This flag is > 0 if we are in a section started by glBegin() in that case we are
@@ -83,27 +83,27 @@ void mogl_checkerrors(const char* cmd, const mxArray *prhs[]);
 
 void mexExitFunction(void)
 {
-  // Release all memory in bufferlist 1 - The one that usually
-  // persists over calls to moglcore.
-  PsychFreeAllTempMemory(1);
-  
-  // Release all memory for persistent GLU tesselator memory list:
-  PsychFreeAllTempMemory(2);
-  PsychFreeAllTempMemory(3);
-  
-  firsttime = 1;
+    // Release all memory in bufferlist 1 - The one that usually
+    // persists over calls to moglcore.
+    PsychFreeAllTempMemory(1);
+
+    // Release all memory for persistent GLU tesselator memory list:
+    PsychFreeAllTempMemory(2);
+    PsychFreeAllTempMemory(3);
+
+    firsttime = 1;
 }
 
 /* This is the main entry point for Matlab or Octave. It gets called by
-   Matlab or Octave, handles first-time initialization, error handling
-   and subfunction dispatching.
-*/
+ * Matlab or Octave, handles first-time initialization, error handling
+ * and subfunction dispatching.
+ */
 void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 {
     // Start of dispatcher:
     int i;
     GLenum err;
-    
+
     // FreeGlut must be initialized, otherwise it will emergency abort the whole application.
     // These variables are needed for it:
     int noargs = 1;
@@ -111,8 +111,8 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     char *dummyargp = &dummyarg[0];
 
     // see whether there's a string command
-    if(nrhs<1 || !mxIsChar(prhs[0])) mogl_usageerr();
-    
+    if (nrhs<1 || !mxIsChar(prhs[0])) mogl_usageerr();
+
     // get string command
     mxGetString(prhs[0],cmd,CMDLEN);
 
@@ -128,14 +128,15 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
         glBeginLevel=0;
         goto moglreturn;
     }
-    
+
     if (strcmp(cmd, "DUMMYMODE")==0) {
         if (nrhs<2 || mxGetScalar(prhs[1])<0) {
             mexErrMsgTxt("MOGL-ERROR: No dummy mode level or invalid level (<0) given for subcommand DUMMYMODE!");
         }
+
         dummymode = (int) mxGetScalar(prhs[1]);
-	if (dummymode>0) printf("MOGL-INFO: Switched to dummy mode level %i.\n", dummymode);
-        goto moglreturn;
+        if (dummymode>0) printf("MOGL-INFO: Switched to dummy mode level %i.\n", dummymode);
+            goto moglreturn;
     }
 
     // Special command to set MOGL debug level:
@@ -152,35 +153,34 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
         debuglevel = (int) mxGetScalar(prhs[1]);
         goto moglreturn;
     }
-    
+
     // Special cleanup subcommand needed for GNU/Octave: See explanation below in firstTime init.
     if (strcmp(cmd, "JettisonModuleHelper")==0) {
-      goto moglreturn;
+        goto moglreturn;
     }
 
     // Abort here if dummymode >= 10: Input arg. processing run, but no real
     // command parsing and processing;
     if (dummymode >= 10) {
-      printf("MOGL-INFO: Dummy call to %s() - Ignored in dummy mode %i ...\n", cmd, dummymode);
-      goto moglreturn;
+        printf("MOGL-INFO: Dummy call to %s() - Ignored in dummy mode %i ...\n", cmd, dummymode);
+        goto moglreturn;
     }
 
     #ifdef BUILD_GLM
     // GLM module is included and supported in moglcore: This is necessary if
     // one wants to use MOGL independent from Psychtoolbox. GLM is only supported
     // on MacOS-X, not on Linux or Windows...
-    
+
     // We execute glm-commands without performing GLEW first-time initialization,
     // because to execute glewinit() we need a valid OpenGL context. This context is
     // either created by Psychtoolbox or by glm. Therefore glm-commands must be able
     // to execute before glewinit() happened.
-    
+
     // look for command in glm command map
     if( (i=binsearch(glm_map,glm_map_count,cmd))>=0 ) {
         glm_map[i].cmdfn(nlhs,plhs,nrhs-1,prhs+1);
         goto moglreturn;
     }
-
     #endif
 
     // Is this the first invocation of moglcore?
@@ -188,27 +188,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
         // Yes. Initialize GLEW, the GL Extension Wrangler Library. This will
         // auto-detect and dynamically link/bind all core OpenGL functionality
         // as well as all possible OpenGL extensions on OS-X, Linux and Windows.
-        err = GLEW_OK;
-        #if defined(PTB_USE_WAFFLE) || defined(PTB_USE_WAYLAND)
-        // Linux is special: If we use the Waffle backend for display system binding, then our display backend
-        // may be something else than GLX (e.g., X11/EGL, Wayland/EGL, GBM/EGL, ANDROID/EGL etc.), in which case
-        // glewInit() would not work and would crash hard. Detect if we're on classic Linux or Linux with X11/GLX.
-        // If so, execute glewInit(), otherwise call glewContextInit() - a routine which skips GLX specific setup,
-        // therefore only initializes the non-GLX parts. We need a hacked glew.c for this function to be available,
-        // as original upstream GLEW makes that function private (static):
-        if (!getenv("PSYCH_USE_DISPLAY_BACKEND") || strstr(getenv("PSYCH_USE_DISPLAY_BACKEND"), "glx")) {
-            // Classic backend or GLX backend: The full show.
-            err = glewInit();
-        }
-        else {
-            // Non-GLX backend, probably EGL: Reduced show.
-            err = glewContextInit();
-        }
-        #else
-            // Other os'es, or Linux without Waffle backend: Always init GLEW:
-            err = glewInit();
-        #endif
-
+        err = glewInit();
         if (GLEW_OK != err) {
             // Failed! Something is seriously wrong - We have to abort :(
             printf("MOGL: Failed to initialize! Probably you called an OpenGL command *before* opening an onscreen window?!?\n");
@@ -217,33 +197,32 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
         }
 
         // Success. Ready to go...
-		if (debuglevel > 1) {
-			printf("MOGL - OpenGL for Matlab & GNU/Octave initialized. MOGL is (c) 2006-2015 Richard F. Murray & Mario Kleiner, licensed to you under MIT license.\n");
+        if (debuglevel > 1) {
+            printf("MOGL - OpenGL for Matlab & GNU/Octave initialized. MOGL is (c) 2006-2016 Richard F. Murray & Mario Kleiner, licensed to you under MIT license.\n");
             #ifdef WINDOWS
-			printf("On MS-Windows, we make use of the freeglut library, which is Copyright (c) 1999-2000 Pawel W. Olszta, licensed under compatible MIT/X11 license.\n");
-            printf("The precompiled Windows binary DLL's have been kindly provided by http://www.transmissionzero.co.uk/software/freeglut-devel/ -- Thanks!\n");
+                printf("On MS-Windows, we make use of the freeglut library, which is Copyright (c) 1999-2000 Pawel W. Olszta, licensed under compatible MIT/X11 license.\n");
+                printf("The precompiled Windows binary DLL's have been kindly provided by http://www.transmissionzero.co.uk/software/freeglut-devel/ -- Thanks!\n");
             #endif
-			printf("See file 'License.txt' in the Psychtoolbox root folder for the exact licensing conditions.\n");
-		}
-        fflush(NULL);
+            printf("See file 'License.txt' in the Psychtoolbox root folder for the exact licensing conditions.\n");
+        }
 
         // Perform dynamic rebinding of ARB extensions to core functions, if necessary:
         mogl_rebindARBExtensionsToCore();
 
-		#ifdef FREEGLUT
-		// FreeGlut must be initialized, otherwise it will emergency abort the whole application.
-		// However, we skip init if we're on a setup without GLX display backend, as this would
-		// abort us due to lack of GLX. On non-GLX we simply can't use FreeGlut at all. Now on
-                // Wayland we'd really like to use FreeGlut and with a XOrg 1.16 server or later we luckily
-                // have XWayland available as a X11/GLX emulation, so we can glutInit() on such a setup if
-                // the DISPLAY variable is defined and signals availability of basic X11/GLX. The fact we don't
-                // use it doesn't matter, as our use of GLUT is restricted to rendering of teapots and other primitives
-                // anyway, and those don't require any Windowing system dependencies in the first place.
-		if (!getenv("PSYCH_USE_DISPLAY_BACKEND") || strstr(getenv("PSYCH_USE_DISPLAY_BACKEND"), "glx") || getenv("DISPLAY")) {
-			// GLX display backend - Init and use FreeGlut:
-			glutInit( &noargs, &dummyargp);
-		}
-		#endif
+        #ifdef FREEGLUT
+            // FreeGlut must be initialized, otherwise it will emergency abort the whole application.
+            // However, we skip init if we're on a setup without GLX display backend, as this would
+            // abort us due to lack of GLX. On non-GLX we simply can't use FreeGlut at all. Now on
+            // Wayland we'd really like to use FreeGlut and with a XOrg 1.16 server or later we luckily
+            // have XWayland available as a X11/GLX emulation, so we can glutInit() on such a setup if
+            // the DISPLAY variable is defined and signals availability of basic X11/GLX. The fact we don't
+            // use it doesn't matter, as our use of GLUT is restricted to rendering of teapots and other primitives
+            // anyway, and those don't require any Windowing system dependencies in the first place.
+            if (!getenv("PSYCH_USE_DISPLAY_BACKEND") || strstr(getenv("PSYCH_USE_DISPLAY_BACKEND"), "glx") || getenv("DISPLAY")) {
+                // GLX display backend - Init and use FreeGlut:
+                glutInit(&noargs, &dummyargp);
+            }
+        #endif
 
         // Running on a OpenGL-ES rendering api under Linux?
         if (getenv("PSYCH_USE_GFX_BACKEND") && strstr(getenv("PSYCH_USE_GFX_BACKEND"), "gles")) {
@@ -327,7 +306,7 @@ void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 int binsearch(cmdhandler *map, int mapsize, char *str) {
     int m=0,n=mapsize-1,i,k,count=0;
     while( m<=n && count < 100) {
-      count++;
+        count++;
         i=(int)((m+n)/2);
         k=strcmp(str,map[i].cmdstr);
         if( k==0 )
@@ -337,7 +316,7 @@ int binsearch(cmdhandler *map, int mapsize, char *str) {
         else
             m=i+1;
     }
-    return( -1 );
+    return(-1);
 }
 
 // error handler
@@ -363,7 +342,7 @@ void mogl_glunsupported(const char* fname)
                     "MOGL-Error: or upgrade your gfx-hardware with more recent one to use this function. Aborted.\n\n", fname);
 
     glBeginLevel = 0;
-    
+
     // Exit to Matlab prompt with error message:
     mexErrMsgTxt(errtxt);
 }
@@ -373,27 +352,27 @@ void mogl_printfexit(const char* str)
 {
     // Reset recursion level for glBegin() / glEnd() statements:
     glBeginLevel = 0;
-    
+
     // Exit to Matlab prompt with error message in 'str':
     mexErrMsgTxt(str);
 }
 
-void mogl_checkerrors(const char* cmd, const mxArray *prhs[]) 
+void mogl_checkerrors(const char* cmd, const mxArray *prhs[])
 {
     char errtxt[10000];
     GLint err, status, handle;
-    
+
     // Reject no-op calls:
     if (debuglevel<=0) return;
-    
+
     // Accounting for glBegin and glEnd calls...
     if (strcmp(cmd, "glBegin")==0) glBeginLevel++;
     if (strcmp(cmd, "glEnd")==0 && glBeginLevel > 0) glBeginLevel--;
-    
+
     // Skip error-checking if we are in the middle of a glBegin(), glEnd() pair.
     // Calling glGetError() in between these two commands itself is an error!
     if (glBeginLevel > 0) return;
-    
+
     // Check for glErrors():
     if ((err=glGetError())>0) {
         // Last command caused an OpenGL error condition: Report it and abort.
@@ -402,7 +381,7 @@ void mogl_checkerrors(const char* cmd, const mxArray *prhs[])
         glBeginLevel = 0;
         mexErrMsgTxt(errtxt);
     }
-    
+
     // No OpenGL core system errors. Check if a special GLSL command was executed:
     if (strcmp(cmd, "glCompileShader")==0) {
         // A GLSL shader got just compiled. Check its compile status...
@@ -419,7 +398,7 @@ void mogl_checkerrors(const char* cmd, const mxArray *prhs[])
         // Exit to Matlab prompt with error message if an error happened.
         if (!status) mexErrMsgTxt("Shader compilation failed!"); else return;
     }
-        
+
     if (strcmp(cmd, "glLinkProgram")==0) {
         // A GLSL shader got just compiled. Check its compile status...
         handle = (GLuint) mxGetScalar(prhs[1]);
@@ -431,7 +410,7 @@ void mogl_checkerrors(const char* cmd, const mxArray *prhs[])
             printf("The program info log for program %i tells us the following:\n", handle);
             printf("%s \n\n", errtxt);
         }
-        
+
         if (debuglevel>1) {
             // Output shader info-log after program validation:
             glValidateProgram(handle);
@@ -449,68 +428,67 @@ void mogl_checkerrors(const char* cmd, const mxArray *prhs[])
 
 // Our memory buffer allocator, adapted from Psychtoolboxs PsychMemory.c
 // allocator:
-
 #define PTBTEMPMEMDEC(n,m) totalTempMemAllocated[(m)] -=(n)
 
 // Enqueues a new record into our linked list of temp. memory buffers.
 // Returns the memory pointer to be passed to rest of Psychtoolbox.
 void* PsychEnqueueTempMemory(void* p, size_t n, int mlist)
 {
-  // Add current buffer-head ptr as next-pointer to our new buffer:
-  *((size_t*) p) = (size_t) PsychTempMemHead[mlist];
+    // Add current buffer-head ptr as next-pointer to our new buffer:
+    *((size_t*) p) = (size_t) PsychTempMemHead[mlist];
 
-  // Set our buffer as new head of list:
-  PsychTempMemHead[mlist] = (size_t*) p;
+    // Set our buffer as new head of list:
+    PsychTempMemHead[mlist] = (size_t*) p;
 
-  // Add allocated buffer size as 2nd element:
-  p = (unsigned char*) p + sizeof(PsychTempMemHead[mlist]);
-  *((size_t*) p) = n;
+    // Add allocated buffer size as 2nd element:
+    p = (unsigned char*) p + sizeof(PsychTempMemHead[mlist]);
+    *((size_t*) p) = n;
 
-  // Accounting:
-  totalTempMemAllocated[mlist] += n;
+    // Accounting:
+    totalTempMemAllocated[mlist] += n;
 
-  // Increment p again to get real start of user-visible buffer:
-  p = (unsigned char*) p + sizeof(n);
+    // Increment p again to get real start of user-visible buffer:
+    p = (unsigned char*) p + sizeof(n);
 
-  // MK TODO FIXME: This can print bogus values if bytecount > INT_MAX ...
-  if (debuglevel > 1) mexPrintf("MOGL: Memlist %i : Allocated new buffer %p of %i Bytes,  new total = %i.\n", mlist, p, n, totalTempMemAllocated[mlist]); fflush(NULL);
+    // MK TODO FIXME: This can print bogus values if bytecount > INT_MAX ...
+    if (debuglevel > 1) mexPrintf("MOGL: Memlist %i : Allocated new buffer %p of %i Bytes,  new total = %i.\n", mlist, p, n, totalTempMemAllocated[mlist]); fflush(NULL);
 
-  // Return ptr:
-  return(p);
+    // Return ptr:
+    return(p);
 }
 
 void *PsychCallocTemp(size_t n, size_t size, int mlist)
 {
-  void *ret;
-  // MK: This could create an overflow if product n * size is
-  // bigger than length of size_t --> Only
-  // happens if more than 4 GB of RAM are allocated at once on
-  // a 32-bit system.
-  // --> Improbable for PTB, unless someones trying a buffer
-  // overflow attack -- PTB would lose there badly anyway...
-  size_t realsize = n * size + sizeof(void*) + sizeof(realsize);
+    void *ret;
+    // MK: This could create an overflow if product n * size is
+    // bigger than length of size_t --> Only
+    // happens if more than 4 GB of RAM are allocated at once on
+    // a 32-bit system.
+    // --> Improbable for PTB, unless someones trying a buffer
+    // overflow attack -- PTB would lose there badly anyway...
+    size_t realsize = n * size + sizeof(void*) + sizeof(realsize);
 
-  // realsize has extra bytes allocated for our little header...  
-  if(NULL==(ret=calloc((size_t) 1, realsize))) {
-    mexErrMsgTxt("MOGL-FATAL ERROR: Out of memory in PsychCallocTemp!\n");
-  }
+    // realsize has extra bytes allocated for our little header...
+    if(NULL==(ret=calloc((size_t) 1, realsize))) {
+        mexErrMsgTxt("MOGL-FATAL ERROR: Out of memory in PsychCallocTemp!\n");
+    }
 
-  // Need to enqueue memory buffer...
-  return(PsychEnqueueTempMemory(ret, realsize, mlist));
+    // Need to enqueue memory buffer...
+    return(PsychEnqueueTempMemory(ret, realsize, mlist));
 }
 
 void *PsychMallocTemp(size_t n, int mlist)
 {
-  void *ret;
+    void *ret;
 
-  // Allocate some extra bytes for our little header...
-  n = n + sizeof(void*) + sizeof(n);
-  if(NULL==(ret=malloc(n))){
-    mexErrMsgTxt("MOGL-FATAL ERROR: Out of memory in PsychMallocTemp!\n");
-  }
+    // Allocate some extra bytes for our little header...
+    n = n + sizeof(void*) + sizeof(n);
+    if(NULL==(ret=malloc(n))){
+        mexErrMsgTxt("MOGL-FATAL ERROR: Out of memory in PsychMallocTemp!\n");
+    }
 
-  // Need to enqueue memory buffer...
-  return(PsychEnqueueTempMemory(ret, n, mlist));
+    // Need to enqueue memory buffer...
+    return(PsychEnqueueTempMemory(ret, n, mlist));
 }
 
 // Free a single spec'd temp memory buffer.
@@ -527,120 +505,120 @@ void *PsychMallocTemp(size_t n, int mlist)
 // but for now this has to be good enough(TM).
 void PsychFreeTemp(void* ptr, int mlist)
 {
-  void* ptrbackup = ptr;
-  size_t* next = PsychTempMemHead[mlist];
-  size_t* prevptr = NULL;
+    void* ptrbackup = ptr;
+    size_t* next = PsychTempMemHead[mlist];
+    size_t* prevptr = NULL;
 
-  if (ptr == NULL) return;
- 
-  // Convert ptb supplied pointer ptr into real start
-  // of our buffer, including our header:
-  ptr = (unsigned char*) ptr - sizeof((unsigned char*) ptr) - sizeof(size_t);
-  if (ptr == NULL) return;
+    if (ptr == NULL) return;
 
-  if (PsychTempMemHead[mlist] == ptr) {
-    // Special case: ptr is first buffer in queue. Dequeue:
-    PsychTempMemHead[mlist] = (size_t*) *(PsychTempMemHead[mlist]);
+    // Convert ptb supplied pointer ptr into real start
+    // of our buffer, including our header:
+    ptr = (unsigned char*) ptr - sizeof((unsigned char*) ptr) - sizeof(size_t);
+    if (ptr == NULL) return;
 
-    // Some accounting:
-    PTBTEMPMEMDEC(((size_t*)ptr)[1], mlist);
-    if (debuglevel > 1) mexPrintf("MOGL: Memlist %i : Freed buffer at %p, new total = %i.\n", mlist, ptrbackup, totalTempMemAllocated[mlist]); fflush(NULL);
+    if (PsychTempMemHead[mlist] == ptr) {
+        // Special case: ptr is first buffer in queue. Dequeue:
+        PsychTempMemHead[mlist] = (size_t*) *(PsychTempMemHead[mlist]);
 
-    // Release it:
-    free(ptr);
+        // Some accounting:
+        PTBTEMPMEMDEC(((size_t*)ptr)[1], mlist);
+        if (debuglevel > 1) mexPrintf("MOGL: Memlist %i : Freed buffer at %p, new total = %i.\n", mlist, ptrbackup, totalTempMemAllocated[mlist]); fflush(NULL);
 
+        // Release it:
+        free(ptr);
+
+        return;
+    }
+
+    // ptr valid and not first buffer in queue.
+    // Walk the whole buffer list until we encounter our buffer:
+    while (next != NULL && next!=ptr) {
+        prevptr = next;
+        next = (size_t*) *next;
+    }
+
+    // Done with search loop. Did we find our buffer?
+    if (next == ptr) {
+        // Found it! Set next-ptr of previous buffer to next-ptr
+        // of this buffer to dequeue from list:
+        *prevptr = *next;
+
+        // Some accounting:
+        PTBTEMPMEMDEC(next[1], mlist);
+        if (debuglevel > 1) mexPrintf("MOGL: Memlist %i: Freed buffer at %p, new total = %i.\n", mlist, ptrbackup, totalTempMemAllocated[mlist]); fflush(NULL);
+
+        // Release:
+        free(ptr);
+
+        // Done.
+        return;
+    }
+
+    // Oops.: Did not find matching buffer to pointer --> Trouble!
+    printf("MOGL-BUG: In PsychFreeTemp: Tried to free non-existent temporary membuffer %p!!! Ignored.\n", ptrbackup);
+    fflush(NULL);
     return;
-  }
-
-  // ptr valid and not first buffer in queue.
-  // Walk the whole buffer list until we encounter our buffer:
-  while (next != NULL && next!=ptr) {
-    prevptr = next;
-    next = (size_t*) *next;
-  }
-
-  // Done with search loop. Did we find our buffer?
-  if (next == ptr) {
-    // Found it! Set next-ptr of previous buffer to next-ptr
-    // of this buffer to dequeue from list:
-    *prevptr = *next;
-
-    // Some accounting:
-    PTBTEMPMEMDEC(next[1], mlist);
-    if (debuglevel > 1) mexPrintf("MOGL: Memlist %i: Freed buffer at %p, new total = %i.\n", mlist, ptrbackup, totalTempMemAllocated[mlist]); fflush(NULL);
-    
-    // Release:
-    free(ptr);
-
-    // Done.
-    return;
-  }
-
-  // Oops.: Did not find matching buffer to pointer --> Trouble!
-  printf("MOGL-BUG: In PsychFreeTemp: Tried to free non-existent temporary membuffer %p!!! Ignored.\n", ptrbackup);
-  fflush(NULL);
-  return;
 }
 
 // Master cleanup routine: Frees all allocated memory:
 void PsychFreeAllTempMemory(int mlist)
 {
-  size_t* p = NULL;
-  size_t* next = PsychTempMemHead[mlist];
+    size_t* p = NULL;
+    size_t* next = PsychTempMemHead[mlist];
 
-  // Walk our whole buffer list and release all buffers on it:
-  while (next != NULL) {
-    // next points to current buffer to release. Make a copy of
-    // next:
-    p = next;
+    // Walk our whole buffer list and release all buffers on it:
+    while (next != NULL) {
+        // next points to current buffer to release. Make a copy of
+        // next:
+        p = next;
 
-    // Update next to point to the next buffer to release:
-    next = (size_t*) *p;
+        // Update next to point to the next buffer to release:
+        next = (size_t*) *p;
 
-    // Some accounting:
-    PTBTEMPMEMDEC(p[1], mlist);
+        // Some accounting:
+        PTBTEMPMEMDEC(p[1], mlist);
 
-    // Release buffer p:
-    free(p);
-    
-    // We're done with this buffer, next points to next one to release
-    // or is NULL if all released...
-  }
+        // Release buffer p:
+        free(p);
 
-  // Done. NULL-out the list start ptr:
-  PsychTempMemHead[mlist] = NULL;
+        // We're done with this buffer, next points to next one to release
+        // or is NULL if all released...
+    }
 
-  // Sanity check:
-  if (totalTempMemAllocated[mlist] != 0) {
-    printf("MOGL-CRITICAL BUG: Inconsistency detected in temporary memory allocator!\n");
-    printf("MOGL-CRITICAL BUG: totalTempMemAllocated[%i] = %i after PsychFreeAllTempMemory(%i)!!!!\n",
-	   mlist, totalTempMemAllocated[mlist], mlist);
-    fflush(NULL);
+    // Done. NULL-out the list start ptr:
+    PsychTempMemHead[mlist] = NULL;
 
-    // Reset to defined state.
-    totalTempMemAllocated[mlist] = 0;
-  }
+    // Sanity check:
+    if (totalTempMemAllocated[mlist] != 0) {
+        printf("MOGL-CRITICAL BUG: Inconsistency detected in temporary memory allocator!\n");
+        printf("MOGL-CRITICAL BUG: totalTempMemAllocated[%i] = %i after PsychFreeAllTempMemory(%i)!!!!\n",
+               mlist, totalTempMemAllocated[mlist], mlist);
+        fflush(NULL);
 
-  if (debuglevel > 1) printf("MOGL: Memlist %i : Freed all internal memory buffers.\n", mlist); fflush(NULL);
+        // Reset to defined state.
+        totalTempMemAllocated[mlist] = 0;
+    }
 
-  return;
+    if (debuglevel > 1) printf("MOGL: Memlist %i : Freed all internal memory buffers.\n", mlist); fflush(NULL);
+
+    return;
 }
 
 // Convert a double value (which encodes a memory address) into a ptr:
-void*  PsychDoubleToPtr(volatile double dptr)
+void* PsychDoubleToPtr(volatile double dptr)
 {
-  volatile psych_uint64* iptr = (psych_uint64*) &dptr;
-  volatile psych_uint64 ival = *iptr;
-  return((void*) ((size_t) ival));
+    volatile psych_uint64* iptr = (psych_uint64*) &dptr;
+    volatile psych_uint64 ival = *iptr;
+    return((void*) ((size_t) ival));
 }
 
 // Convert a memory address pointer into a double value:
 double PsychPtrToDouble(void* ptr)
 {
-  volatile psych_uint64 ival = (psych_uint64) ((size_t) ptr);
-  volatile double* dptr = (double*) &ival;
-  volatile double outval = *dptr;
-  return(outval);
+    volatile psych_uint64 ival = (psych_uint64) ((size_t) ptr);
+    volatile double* dptr = (double*) &ival;
+    volatile double outval = *dptr;
+    return(outval);
 }
 
 // Return the size of the buffer pointed to by ptr in bytes.
@@ -651,31 +629,31 @@ double PsychPtrToDouble(void* ptr)
 // for the buffer-header).
 size_t PsychGetBufferSizeForPtr(void* ptr)
 {
-  size_t mysize;
+    size_t mysize;
 
-  // Decrement pointer to let it point to our size field in the buffer-header:
-  ptr = (unsigned char*) ptr - sizeof(size_t);
+    // Decrement pointer to let it point to our size field in the buffer-header:
+    ptr = (unsigned char*) ptr - sizeof(size_t);
 
-  // Retrieve size value in header, subtract size of header itself:
-  mysize = (*((size_t*) ptr)) - sizeof(void*) - sizeof(size_t);
+    // Retrieve size value in header, subtract size of header itself:
+    mysize = (*((size_t*) ptr)) - sizeof(void*) - sizeof(size_t);
 
-  // Return it:
-  return((size_t) mysize);
+    // Return it:
+    return((size_t) mysize);
 }
 
 // Mapping of scalar buffer offset value (in units of bytes) to an
 // equivalent memory void*. Handles doubles, uint32 and uint64:
 void* moglScalarToPtrOffset(const mxArray *m) {
-	if (mxIsDouble(m)) return((void*) (size_t) mxGetScalar(m));
-	if (mxIsUint32(m)) return((void*) (size_t) (((unsigned int*) mxGetData(m))[0]));
+    if (mxIsDouble(m)) return((void*) (size_t) mxGetScalar(m));
+    if (mxIsUint32(m)) return((void*) (size_t) (((unsigned int*) mxGetData(m))[0]));
 
     #ifndef MATLABR11
     if (mxIsUint64(m)) return((void*) (size_t) (((psych_uint64*) mxGetData(m))[0]));
-	#endif
-    
-	// Invalid input type - Error abort:
+    #endif
+
+    // Invalid input type - Error abort:
     glBeginLevel = 0;
     printf("MOGL-Command: %s\n", cmd);
-	mexErrMsgTxt("Provided pointer or buffer offset argument is of invalid type - Not double, uint32 or uint64!");
-	return(NULL);
+    mexErrMsgTxt("Provided pointer or buffer offset argument is of invalid type - Not double, uint32 or uint64!");
+    return(NULL);
 }
