@@ -1,5 +1,5 @@
-function VBLSyncTest(n, numifis, loadjitter, clearmode, stereo, flushpipe, synchronous, usedpixx, screenNumber)
-% VBLSyncTest(n, numifis, loadjitter, clearmode, stereo, flushpipe, synchronous, usedpixx, screenNumber)
+function VBLSyncTest(n, numifis, loadjitter, clearmode, stereo, flushpipe, synchronous, usedpixx, usevulkan, screenNumber)
+% VBLSyncTest([n=600][, numifis=0][, loadjitter=0][, clearmode=0][, stereo=0][, flushpipe=0][, synchronous=0][, usedpixx=0][, usevulkan=0][, screenNumber=max])
 %
 % Tests syncing of Psychtoolbox to the vertical retrace (VBL) and demonstrates
 % how to implement the old Screen('WaitBlanking') behaviour with
@@ -112,6 +112,10 @@ function VBLSyncTest(n, numifis, loadjitter, clearmode, stereo, flushpipe, synch
 % and DataPixx device.
 %
 %
+% 'usevulkan' If 1, try to use a Vulkan display backend instead of the
+% OpenGL display backend. See 'help PsychVulkan'.
+%
+%
 % screenNumber =  Use a screen other than the default (max) for testing .
 %
 %
@@ -240,7 +244,11 @@ if nargin < 8 || isempty(usedpixx)
     usedpixx = 0;
 end
 
-if nargin < 9
+if nargin < 9 || isempty(usevulkan)
+    usevulkan = 0;
+end
+
+if nargin < 10
     screenNumber = [];
 end
 
@@ -277,11 +285,16 @@ try
         PsychImaging('AddTask', 'General', 'UseDataPixx');
     end
 
+    if usevulkan
+        % Use PsychVulkan display backend instead of standard OpenGL:
+        PsychImaging('AddTask', 'General', 'UseVulkanDisplay');
+    end
+
     if 0
         w=PsychImaging('OpenWindow',screenNumber, 0,[0 0 1430 900],[],[], stereo);
         Screen('GetFlipInfo', w, 1);
     else
-        w=PsychImaging('OpenWindow',screenNumber, 0,[],[],[], stereo);
+        w=PsychImaging('OpenWindow',screenNumber, 0, [],[],[], stereo);
     end
     
     % Query effective stereo mode, as Screen() could have changed it behind our
