@@ -378,6 +378,14 @@ if IsOctave
 
         fprintf('Octave major version %i detected. Will prepend the following folder to your Octave path:\n', octavemajorv);
 
+        % Octave on Linux with ARM processor, e.g., RaspberryPi?
+        if IsLinux && IsARM
+            % 32-Bit ARM can currently share mex files from Octave 3.8 to at least 5.x,
+            % so treat it as Octave 3.8, and all versions will share the same folder:
+            octavemajorv = 3;
+            octaveminorv = 8;
+        end
+
         if ((octavemajorv >= 5) || (octavemajorv == 4 && octaveminorv >= 4)) && IsLinux
             % Octave-4.4 and Octave-5 can share the same mex files in the Octave-5 folder on Linux:
             rdir = [PsychtoolboxRoot 'PsychBasic' filesep 'Octave5'];
@@ -658,7 +666,7 @@ try
         % warning. We skip this on Linux, as the OS will take care of
         % proper rebuilds appropriately, so we don't expect to ever run
         % into this problem:
-        fprintf('Trying to trigger an update of the fontconfig cache if that should prove neccessary.\n');
+        fprintf('\n\nTrying to trigger an update of the fontconfig cache if that should prove neccessary.\n');
         fprintf('This may take a couple of seconds, or sometimes even minutes. Please be patient...\n');
         drawnow;
 
@@ -677,8 +685,15 @@ try
             Screen('DrawText', win, 'Ola!');
             Screen('Flip', win);
             sca;
+
+            if Screen('Preference', 'TextRenderer') == 0
+                % Failed to load drawtext plugin.
+                warning('Something went wrong with high-quality text renderer setup. Read ''help DrawTextPlugin'' for troubleshooting.');
+                input('Press Return key to continue.', 's');
+            end
         catch
-            fprintf('Something went wrong with text renderer setup. Read ''help DrawTextPlugin'' for troubleshooting.\n\n\n');
+            warning('Something went wrong with high-quality text renderer setup. Read ''help DrawTextPlugin'' for troubleshooting.');
+            input('Press Return key to continue.', 's');
         end
 
         Screen('Preference', 'TextRenderer', oldRenderer);
